@@ -135,6 +135,7 @@ $_gmsg['l_allowdirectaccess'] = 'Allow Direct Access';
 $_gmsg['l_allowedRobotHits'] = 'Allowed Robot Hits';
 $_gmsg['l_allowedhosts'] = 'Allowed Domains';
 $_gmsg['l_allowoverride'] = 'Allow Override';
+$_gmsg['l_allowquic'] = 'Allow QUIC';
 $_gmsg['l_allowsetuid'] = 'Allow Set UID';
 $_gmsg['l_allowsymbollink'] = 'Follow Symbolic Link';
 $_gmsg['l_apachebinpath'] = 'Apache Binary Path';
@@ -239,6 +240,7 @@ $_gmsg['l_enabled'] = 'Enabled';
 $_gmsg['l_enabledhe'] = 'Enable DH Key Exchange';
 $_gmsg['l_enabledyngzipcompress'] = 'Enable Dynamic Compression';
 $_gmsg['l_enableecdhe'] = 'Enable ECDH Key Exchange';
+$_gmsg['l_enablequic'] = 'Enable QUIC';
 $_gmsg['l_enableexpires'] = 'Enable Expires';
 $_gmsg['l_enablegzip'] = 'Enable GZIP Compression';
 $_gmsg['l_enableh2c'] = 'Enable HTTP/2 Over Cleartext TCP';
@@ -541,6 +543,16 @@ $_gmsg['l_workers'] = 'Workers';
 $_gmsg['l_workingdir'] = 'Working Directory';
 $_gmsg['l_wsgibin'] = 'WSGI Path';
 $_gmsg['l_wsgisettings'] = 'Python WSGI Default Settings';
+$_gmsg['l_quic'] = 'QUIC';
+$_gmsg['l_quicshmdir'] = 'QUIC SHM Directory';
+$_gmsg['l_quicversions'] = 'QUIC Versions';
+$_gmsg['l_quiccfcw'] = 'Connection Flow Control Window';
+$_gmsg['l_quicmaxcfcw'] = 'Max Connection Flow Control Window';
+$_gmsg['l_quicsfcw'] = 'Stream Flow Control Window';
+$_gmsg['l_quicmaxsfcw'] = 'Max Stream Flow Control Window';
+$_gmsg['l_quicmaxstreams'] = 'Max Concurrent Streams Per Connection';
+$_gmsg['l_quichandshaketimeout'] = 'Handshake Timeout (secs)';
+$_gmsg['l_quicidletimeout'] = 'Idle Timeout (secs)';
 
 
 $_gmsg['o_cagefswithoutsuexec'] = 'CageFS without suEXEC';
